@@ -103,6 +103,10 @@ gucharmap_get_unicode_name (gunichar wc)
       g_snprintf (buf, sizeof (buf), "NUSHU CHARACTER-%05X", wc);
       return buf;
   }
+  else if (wc >= 0x13460 && wc <= 0x143fa) {
+      g_snprintf (buf, sizeof (buf), "EGYPTIAN HIEROGLYPH-%05X", wc);
+      return buf;
+  }
   else if (wc >= 0xac00 && wc <= 0xd7af)
     {
       /* compute hangul syllable name as per UAX #15 */
